==> webIfesProjects_2022-03-24_22-15-50.tar.gz: WebProjects/CustomSkripts/kommentar.php <==
<?php
// echo "TEST<pre>";
// var_dump($_POST);
// var_dump($_GET);
// echo "</pre>";
$server = array(
    //'mysql' => "warpit2-dev.ifes.at",
    'mysql' => "localhost",
    'port' => "3307",
    // 'user' => 'warpit',
    // 'pw' => 'KaehohV2aing',
    'user' => 'root',
    'pw' => '',
    'defaultDb' => 'Warpit_Webcati_base');
    try
    { 	$dbConnection =    new PDO('mysql:host=' . $server['mysql'] . ';port=' . $server['port'] . ';dbname=' . $server['defaultDb'], $server['user'], $server['pw'], array(PDO::MYSQL_ATTR_INIT_COMMAND => 'SET NAMES utf8'));
        // echo "\n".$server['mysql']." - SUCCESS\n";
    }
    catch (PDOException $e)
    { 	$logtxt = $e->getMessage();
        logText(LOG_PATH, "\n\n" . date('[d/M/Y H:i:s]') . "\n" . $logtxt, FILE_APPEND | LOCK_EX);
        echo"\n".$server['mysql']." - ERROR:".$logtxt."\n";
        die();
    }
    // echo "TEST2";
if(isset($_POST["qname"])) {
    $qname = $_POST["qname"];
    $comment =  $_POST["text"];
    $idUser =  $_POST["idUser"];
    $loginSID =  $_POST["loginSID"];
    $idRecord =  $_POST["idRecord"];
    $update =   $_POST["update"];
    // echo "<pre>";
    // var_dump($_POST);
    // echo "<br>TEST3<br>";
    if ($update == 0) {
        $query="INSERT INTO Warpit_Webcati_base.HFCS99_Kommentar_structure (user_id,id_loginSID,idRecord_1,quest_1,comment_1) VALUES (".$idUser.",".$loginSID.",'".$idRecord."','".$qname."','".$comment."');";
    }
    if ($update == 1) {
        $query="UPDATE Warpit_Webcati_base.HFCS99_Kommentar_structure SET comment_1 = '".$comment."' WHERE user_id=".$idUser." and id_loginSID=".$loginSID." and idRecord_1='".$idRecord."' and quest_1='".$qname."';";
    }
    // echo "<br>".$query."<br>";

    $pdo_select = $dbConnection->prepare($query);
    if ($pdo_select->execute()) {
	    $pdo_select->fetchAll(PDO::FETCH_ASSOC);}
    else {
			global $logtxt;
			$errtxt = date('[d/M/Y H:i:s]')."\nSQL-Statement \n'".$query."'\n konnte nicht ausgefuehrt werden.\n";
			echo $errtxt;
			$logtxt .= $errtxt;
		}
    echo "<script>
    window.close();
    </script>";

} else {
    $update = 0;
    $qname = $_GET["qname"];
    $comment =  '';
    $idUser =  $_GET["idUser"];
    $loginSID =  $_GET["loginSID"];
    $idRecord =  $_GET["idRecord"];
    $query = "SELECT comment_1 FROM Warpit_Webcati_base.HFCS99_Kommentar_structure WHERE user_id=".$idUser." and id_loginSID=".$loginSID." and idRecord_1='".$idRecord."' and quest_1='".$qname."'";
    // echo "<br>".$query."<br>";
    $pdo_select = $dbConnection->prepare($query);
    if ($pdo_select->execute()) {
        $result = $pdo_select->fetchAll(PDO::FETCH_ASSOC);
        // echo "ANZAL: ".count($result)."<br>";
        // var_dump($result);
        $comment = $result[count($result)-1]["comment_1"];
        // echo "Importiertes Kommentar: ".$comment."<br>";
        if (count($result)>=1) $update=1;
    } else {
        global $logtxt;
        $errtxt = date('[d/M/Y H:i:s]')."\nSQL-Statement \n'".$query."'\n konnte nicht ausgefuehrt werden.\n";
        echo $errtxt;
        $logtxt .= $errtxt;
    }

    // var_dump($_GET);
    }
    ?>
<!DOCTYPE html>
<html lang="de">
  <head>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <title>Titel</title>
  </head>
  <body>
    <form action=""  method="post">
		<label for="text">Kommentar zur Frage <?php echo $qname; ?></label><br>
		<textarea id="text" name="text" cols="35" rows="4" ><?php echo $comment; ?></textarea><br>
		<input type="hidden" id="qName" name="qname" value=<?php echo $qname; ?>>
		<input type="hidden" id="idUser" name="idUser" value=<?php echo $idUser; ?>>
		<input type="hidden" id="loginSID" name="loginSID" value=<?php echo $loginSID; ?>>
		<input type="hidden" id="idRecord" name="idRecord" value=<?php echo $idRecord; ?>>
		<input type="hidden" id="update" name="update" value=<?php echo $update; ?>>
    <?php
    echo "<pre>";
    // var_dump($GLOBALS);
    echo "</pre>";
    ?>
    <input type="submit" value="Senden"></form>
  </body>
</html>
<?php
// }
 ?>

==> webIfesProjects_2022-03-24_23-04-32.tar.gz: WebProjects/CustomSkripts/kommentar.php <==
<?php
//  echo "TEST<pre>";
//  var_dump($_POST);
//  var_dump($_GET);
//  var_dump($_GET["serverBase"]);
//  var_dump($_POST["serverBase"]);
//exit;
$server_array = array(
  "warpit2-dev.ifes.at" => array(
    'mysql' => "localhost",
    //  'mysql' => "warpit2-dev.ifes.at",
    'portstr' => "",
    'user' => 'warpit',
    'pw' => 'KaehohV2aing',
    'defaultDb' => 'Warpit_Webcati_base',
  ),
  "wp-capi1-prod.ad.ifes.at" => array(
    'mysql' => "localhost",
    //  'mysql' => "warpit2-dev.ifes.at",
    'portstr' => "",
    'user' => 'ifes',
    'pw' => 'Eif1weiPheiP',
    'defaultDb' => 'Warpit_Webcati_base',
  ),
  "localhost" => array(
    'mysql' => "localhost",
    'portstr' => ";port=3307",
    'user' => 'root',
    'pw' => '',
    'defaultDb' => 'Warpit_Webcati_base',
  ),
);
  $server = $server_array[$_GET["serverBase"]];
  // var_dump($server);

  // var_dump($GLOBALS);
  // echo "</pre>";
    try
    { 	$dbConnection =    new PDO('mysql:host=' . $server['mysql'] . $server['portstr'].';dbname=' . $server['defaultDb'], $server['user'], $server['pw'], array(PDO::MYSQL_ATTR_INIT_COMMAND => 'SET NAMES utf8'));
        // echo "\n".$server['mysql']." - SUCCESS\n";
    }
    catch (PDOException $e)
    { 	$logtxt = $e->getMessage();
        logText(LOG_PATH, "\n\n" . date('[d/M/Y H:i:s]') . "\n" . $logtxt, FILE_APPEND | LOCK_EX);
        echo"\n".$server['mysql']." - ERROR:".$logtxt."\n";
        die();
    }
    // echo "TEST2";
if(isset($_POST["qname"])) {
    $qname = $_POST["qname"];
    $comment =  str_replace(array(";","'"),"",$_POST["text"]);
    $idUser =  $_POST["idUser"];
    $loginSID =  $_POST["loginSID"];
    $idRecord =  $_POST["idRecord"];
    $update =   $_POST["update"];
    $frabo =    $_POST["projectName"];
    $EV_id_record =    $_POST["EVidRecord"];
    // echo "<pre>";
    // var_dump($_POST);
    // echo "<br>".$_POST["projectName"]."<br>";
    if ($update == 0) {
        $query="INSERT INTO Warpit_Webcati_base.HFCS99_Kommentar_structure (user_id,id_loginSID,idRecord_1,quest_1,comment_1,EV_id_record,frabo) VALUES (".$idUser.",".$loginSID.",'".$idRecord."','".$qname."','".$comment."','".$EV_id_record."','".$frabo."');";
    }
    if ($update == 1) {
        $query="UPDATE Warpit_Webcati_base.HFCS99_Kommentar_structure SET comment_1 = '".$comment."' WHERE user_id=".$idUser." and id_loginSID=".$loginSID." and idRecord_1='".$idRecord."' and quest_1='".$qname."';";
    }
     echo "<br>".$query."<br>";

    $pdo_select = $dbConnection->prepare($query);
    if ($pdo_select->execute()) {
	    $pdo_select->fetchAll(PDO::FETCH_ASSOC);}
    else {
			global $logtxt;
			$errtxt = date('[d/M/Y H:i:s]')."\nSQL-Statement \n'".$query."'\n konnte nicht ausgefuehrt werden.\n";
			echo $errtxt;
			$logtxt .= $errtxt;
		}
    echo "<script>
    window.close();
    </script>";

} else {
    $update = 0;
    $qname = $_GET["qname"];
    $comment =  '';
    $idUser =  $_GET["idUser"];
    $loginSID =  $_GET["loginSID"];
    $idRecord =  $_GET["idRecord"];
    $frabo =    $_GET["projectName"];
    $EV_id_record =    $_GET["EVidRecord"];
    $query = "SELECT comment_1 FROM Warpit_Webcati_base.HFCS99_Kommentar_structure WHERE user_id=".$idUser." and id_loginSID=".$loginSID." and idRecord_1='".$idRecord."' and quest_1='".$qname."'";
    // echo "<br>".$query."<br>";
    $pdo_select = $dbConnection->prepare($query);
    if ($pdo_select->execute()) {
        $result = $pdo_select->fetchAll(PDO::FETCH_ASSOC);
        // echo "ANZAL: ".count($result)."<br>";
        // var_dump($result);
        if (count($result)>=1) {
          $update=1;
          $comment = $result[count($result)-1]["comment_1"];
        }
        // echo "Importiertes Kommentar: ".$comment."<br>";
    } else {
        global $logtxt;
        $errtxt = date('[d/M/Y H:i:s]')."\nSQL-Statement \n'".$query."'\n konnte nicht ausgefuehrt werden.\n";
        echo $errtxt;
        $logtxt .= $errtxt;
    }
    // echo "GETS";
    //  var_dump($_GET);
    }
    ?>
<!DOCTYPE html>
<html lang="de">
  <head>
    <meta charset="utf-8" />
    <meta name="viewport" content="width=device-width, initial-scale=1.0" />
    <title>Titel</title>
  </head>
  <body>
    <form action=""  method="post">
		<label for="text">Kommentar zur Frage <?php echo $qname; ?></label><br>
		<textarea id="text" name="text" cols="35" rows="4" ><?php echo $comment; ?></textarea><br>
		<input type="hidden" id="qName" name="qname" value=<?php echo $qname; ?>>
		<input type="hidden" id="idUser" name="idUser" value=<?php echo $idUser; ?>>
		<input type="hidden" id="loginSID" name="loginSID" value=<?php echo $loginSID; ?>>
		<input type="hidden" id="idRecord" name="idRecord" value=<?php echo $idRecord; ?>>
		<input type="hidden" id="EVidRecord" name="EVidRecord" value=<?php echo $EV_id_record; ?>>
		<input type="hidden" id="projectName" name="projectName" value=<?php echo $frabo; ?>>
		<input type="hidden" id="update" name="update" value=<?php echo $update; ?>>
    <?php
    echo "<pre>";
    // var_dump($GLOBALS);
    echo "</pre>";
    ?>
    <input type="submit" value="Senden"></form>
  </body>
</html>
<?php
// }
 ?>
